==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QCustomAudioRoleControl_shell.h <==
#ifndef QCUSTOMAUDIOROLECONTROL_SHELL_H
#define QCUSTOMAUDIOROLECONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcustomaudiorolecontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QCustomAudioRoleControl_shell : public QCustomAudioRoleControl, public QtJambiShellInterface
{
public:
    QCustomAudioRoleControl_shell(QObject* parent0 = nullptr);
    ~QCustomAudioRoleControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QString customAudioRole() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setCustomAudioRole(const QString& role0) override;
    QStringList supportedCustomAudioRoles() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCustomAudioRoleControl_access : public QCustomAudioRoleControl
{
    jstring __qt_customAudioRole(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCustomAudioRole_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring role0);
    jobject __qt_supportedCustomAudioRoles(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QCUSTOMAUDIOROLECONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QCustomAudioRoleControl_shell.h <==
#ifndef QCUSTOMAUDIOROLECONTROL_SHELL_H
#define QCUSTOMAUDIOROLECONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcustomaudiorolecontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QCustomAudioRoleControl_shell : public QCustomAudioRoleControl, public QtJambiShellInterface
{
public:
    QCustomAudioRoleControl_shell(QObject* parent0 = nullptr);
    ~QCustomAudioRoleControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QString customAudioRole() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setCustomAudioRole(const QString& role0) override;
    QStringList supportedCustomAudioRoles() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCustomAudioRoleControl_access : public QCustomAudioRoleControl
{
    jstring __qt_customAudioRole_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCustomAudioRole_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring role0);
    jobject __qt_supportedCustomAudioRoles_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QCUSTOMAUDIOROLECONTROL_SHELL_H
